@@ -306,6 +306,34 @@ class TemClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeRelatedIngresses(self, request):
+        """查询服务关联的 Ingress 规则列表
+
+        :param request: Request instance for DescribeRelatedIngresses.
+        :type request: :class:`tencentcloud.tem.v20201221.models.DescribeRelatedIngressesRequest`
+        :rtype: :class:`tencentcloud.tem.v20201221.models.DescribeRelatedIngressesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeRelatedIngresses", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeRelatedIngressesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeServiceRunPodListV2(self, request):
         """获取服务下面运行pod列表
 
@@ -334,6 +362,34 @@ class TemClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def GenerateDownloadUrl(self, request):
+        """生成包预签名下载链接
+
+        :param request: Request instance for GenerateDownloadUrl.
+        :type request: :class:`tencentcloud.tem.v20201221.models.GenerateDownloadUrlRequest`
+        :rtype: :class:`tencentcloud.tem.v20201221.models.GenerateDownloadUrlResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GenerateDownloadUrl", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GenerateDownloadUrlResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyIngress(self, request):
         """创建或者更新 Ingress 规则
 
@@ -383,6 +439,62 @@ class TemClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ModifyServiceInfo(self, request):
+        """修改服务基本信息
+
+        :param request: Request instance for ModifyServiceInfo.
+        :type request: :class:`tencentcloud.tem.v20201221.models.ModifyServiceInfoRequest`
+        :rtype: :class:`tencentcloud.tem.v20201221.models.ModifyServiceInfoResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyServiceInfo", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyServiceInfoResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def RestartServiceRunPod(self, request):
+        """重启实例
+
+        :param request: Request instance for RestartServiceRunPod.
+        :type request: :class:`tencentcloud.tem.v20201221.models.RestartServiceRunPodRequest`
+        :rtype: :class:`tencentcloud.tem.v20201221.models.RestartServiceRunPodResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RestartServiceRunPod", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RestartServiceRunPodResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
