@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -68,6 +70,13 @@ class AddCustomRuleRequest(AbstractModel):
         self.Redirect = params.get("Redirect")
         self.Edition = params.get("Edition")
         self.Bypass = params.get("Bypass")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AddCustomRuleResponse(AbstractModel):
@@ -96,6 +105,49 @@ class AddCustomRuleResponse(AbstractModel):
             self.Success._deserialize(params.get("Success"))
         self.RuleId = params.get("RuleId")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class BotStatPointItem(AbstractModel):
+    """bot的趋势图对象
+
+    """
+
+    def __init__(self):
+        """
+        :param TimeStamp: 横坐标
+        :type TimeStamp: str
+        :param Key: value的所属对象
+        :type Key: str
+        :param Value: 纵列表
+        :type Value: int
+        :param Label: Key对应的页面展示内容
+        :type Label: str
+        """
+        self.TimeStamp = None
+        self.Key = None
+        self.Value = None
+        self.Label = None
+
+
+    def _deserialize(self, params):
+        self.TimeStamp = params.get("TimeStamp")
+        self.Key = params.get("Key")
+        self.Value = params.get("Value")
+        self.Label = params.get("Label")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateAttackDownloadTaskRequest(AbstractModel):
@@ -145,6 +197,13 @@ class CreateAttackDownloadTaskRequest(AbstractModel):
         self.RuleId = params.get("RuleId")
         self.AttackIp = params.get("AttackIp")
         self.AttackType = params.get("AttackType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateAttackDownloadTaskResponse(AbstractModel):
@@ -166,6 +225,13 @@ class CreateAttackDownloadTaskResponse(AbstractModel):
     def _deserialize(self, params):
         self.Flow = params.get("Flow")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteAttackDownloadRecordRequest(AbstractModel):
@@ -183,6 +249,13 @@ class DeleteAttackDownloadRecordRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Id = params.get("Id")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteAttackDownloadRecordResponse(AbstractModel):
@@ -200,6 +273,13 @@ class DeleteAttackDownloadRecordResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteDownloadRecordRequest(AbstractModel):
@@ -217,6 +297,13 @@ class DeleteDownloadRecordRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.Flow = params.get("Flow")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteDownloadRecordResponse(AbstractModel):
@@ -234,6 +321,13 @@ class DeleteDownloadRecordResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteSessionRequest(AbstractModel):
@@ -255,6 +349,13 @@ class DeleteSessionRequest(AbstractModel):
     def _deserialize(self, params):
         self.Domain = params.get("Domain")
         self.Edition = params.get("Edition")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DeleteSessionResponse(AbstractModel):
@@ -277,6 +378,13 @@ class DeleteSessionResponse(AbstractModel):
     def _deserialize(self, params):
         self.Data = params.get("Data")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCustomRulesPagingInfo(AbstractModel):
@@ -298,6 +406,13 @@ class DescribeCustomRulesPagingInfo(AbstractModel):
     def _deserialize(self, params):
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCustomRulesRequest(AbstractModel):
@@ -333,6 +448,13 @@ class DescribeCustomRulesRequest(AbstractModel):
         self.Edition = params.get("Edition")
         self.ActionType = params.get("ActionType")
         self.Search = params.get("Search")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCustomRulesResponse(AbstractModel):
@@ -363,6 +485,13 @@ class DescribeCustomRulesResponse(AbstractModel):
                 self.RuleList.append(obj)
         self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeCustomRulesRspRuleListItem(AbstractModel):
@@ -421,6 +550,78 @@ class DescribeCustomRulesRspRuleListItem(AbstractModel):
                 obj = Strategy()
                 obj._deserialize(item)
                 self.Strategies.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class DescribeFlowTrendRequest(AbstractModel):
+    """DescribeFlowTrend请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Domain: 需要获取流量趋势的域名, all表示所有域名
+        :type Domain: str
+        :param StartTs: 起始时间戳，精度秒
+        :type StartTs: int
+        :param EndTs: 结束时间戳，精度秒
+        :type EndTs: int
+        """
+        self.Domain = None
+        self.StartTs = None
+        self.EndTs = None
+
+
+    def _deserialize(self, params):
+        self.Domain = params.get("Domain")
+        self.StartTs = params.get("StartTs")
+        self.EndTs = params.get("EndTs")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
+
+
+class DescribeFlowTrendResponse(AbstractModel):
+    """DescribeFlowTrend返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Data: 流量趋势数据
+        :type Data: list of BotStatPointItem
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Data = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Data") is not None:
+            self.Data = []
+            for item in params.get("Data"):
+                obj = BotStatPointItem()
+                obj._deserialize(item)
+                self.Data.append(obj)
+        self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeUserClbWafRegionsRequest(AbstractModel):
@@ -449,6 +650,13 @@ class DescribeUserClbWafRegionsResponse(AbstractModel):
     def _deserialize(self, params):
         self.Data = params.get("Data")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyCustomRuleStatusRequest(AbstractModel):
@@ -478,6 +686,13 @@ class ModifyCustomRuleStatusRequest(AbstractModel):
         self.RuleId = params.get("RuleId")
         self.Status = params.get("Status")
         self.Edition = params.get("Edition")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ModifyCustomRuleStatusResponse(AbstractModel):
@@ -501,6 +716,13 @@ class ModifyCustomRuleStatusResponse(AbstractModel):
             self.Success = ResponseCode()
             self.Success._deserialize(params.get("Success"))
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ResponseCode(AbstractModel):
@@ -522,6 +744,13 @@ class ResponseCode(AbstractModel):
     def _deserialize(self, params):
         self.Code = params.get("Code")
         self.Message = params.get("Message")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class Strategy(AbstractModel):
@@ -550,4 +779,11 @@ class Strategy(AbstractModel):
         self.Field = params.get("Field")
         self.CompareFunc = params.get("CompareFunc")
         self.Content = params.get("Content")
-        self.Arg = params.get("Arg")
\ No newline at end of file
+        self.Arg = params.get("Arg")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
\ No newline at end of file
